@@ -2,10 +2,5 @@ from .dataset import TFDataset
 from .masked_lm_dataset import TFDatasetForMaksedLanguageModel
 from .question_answering_dataset import TFDatasetForQuestionAnswering
 from .sequence_classification_dataset import TFDatasetForSequenceClassifiation
-from .simcse_dataset import (
-    TFDatasetForHardNegativeSimCSE,
-    TFDatasetForSimCSE,
-    TFDatasetForSupervisedSimCSE,
-    TFDatasetForUnsupSimCSE,
-)
+from .simcse_dataset import TFDatasetForSimCSE
 from .token_classification_dataset import TFDatasetForTokenClassification
